
/*  Inicio Creacion de triggers */

SET ECHO ON;
/*
    NOMBRE:  TRG_BIT_FACTURA
    TABLA:   T_FACTURA
    TIPO:    BI
    PROCESO: TODA FACTURA DEBE COMENZAR CON NITEMS = 0, MONTO = 0
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BIT_FACTURA  FOR T_FACTURA
   BEFORE INSERT
   AS
   BEGIN
      NEW.NITEMS = 0;
      NEW.MONTO  = 0;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BUT_FACTURA
    TABLA:   T_FACTURA
    TIPO:    BU
    PROCESO: NO PERMITO CAMBIO DE NRO
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BUT_FACTURA  FOR T_FACTURA
   BEFORE UPDATE
   AS
   BEGIN
      IF ( OLD.NRO <> NEW.NRO ) THEN EXCEPTION EX_T_DETALLE2;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BUT_DETALLE
    TABLA:   T_DETALLE
    TIPO:    BU
    PROCESO: NO PERMITO CAMBIO DE NRO DE FACTURA

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BUT_DETALLE  FOR T_DETALLE
   BEFORE UPDATE
   AS
   BEGIN
      IF ( OLD.NRO <> NEW.NRO ) THEN EXCEPTION EX_T_DETALLE2;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_AUT_DETALLE
    TABLA:   T_DETALLE
    TIPO:    AU
    PROCESO: SI MODIFICO CANTIDAD O PRECIO, ACTUALIZO MONTO FACTURA

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_AUT_DETALLE  FOR T_DETALLE
   AFTER UPDATE
   AS
   BEGIN
      IF ( (OLD.CANTIDAD <> NEW.CANTIDAD) OR (OLD.PRECIO <> NEW.PRECIO) ) THEN 
         UPDATE T_FACTURA SET MONTO = MONTO - (OLD.CANTIDAD*OLD.PRECIO) + (NEW.CANTIDAD*NEW.PRECIO)
         WHERE NRO = NEW.NRO;
   END !!
SET TERM ; !!


SET ECHO ON;
/*
    NOMBRE:  TRG_BIT_DETALLE
    TABLA:   T_DETALLE
    TIPO:    BI
    PROCESO: VERIFICAR QUE NITEMS NO SEA >= 10

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BIT_DETALLE  FOR T_DETALLE
   BEFORE INSERT
   AS
      DECLARE VARIABLE N INTEGER;
   BEGIN
      SELECT NITEMS FROM T_FACTURA WHERE NRO = NEW.NRO INTO :N;
      IF ( N >= 10 ) THEN EXCEPTION EX_T_DETALLE1;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_AIT_DETALLE
    TABLA:   T_DETALLE
    TIPO:    AI
    PROCESO: INCREMENTAR NITEMS, ACUMULAR MONTO

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_AIT_DETALLE  FOR T_DETALLE
   AFTER INSERT
   AS
   BEGIN
      UPDATE T_FACTURA SET NITEMS = NITEMS + 1,
                           MONTO = MONTO + (NEW.CANTIDAD*NEW.PRECIO) 
      WHERE NRO = NEW.NRO;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_ADT_DETALLE
    TABLA:   T_DETALLE
    TIPO:    AD
    PROCESO: DECREMENTAR NITEMS, DECREMENTAR MONTO

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_ADT_DETALLE  FOR T_DETALLE
   AFTER DELETE
   AS
   BEGIN
      UPDATE T_FACTURA SET NITEMS = NITEMS - 1,
                           MONTO = MONTO - (OLD.CANTIDAD*OLD.PRECIO)
      WHERE NRO = OLD.NRO;
   END !!
SET TERM ; !!

SHOW TRIGGERS;

SET ECHO ON;

/*  Fin Creacion de triggers */
