
/*  Inicio Creacion de triggers */

SET ECHO ON;
/*
    NOMBRE:  TRG_BIT_LIBRO
    TABLA:   T_LIBRO
    TIPO:    BI
    PROCESO: NEJ=0
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BIT_LIBRO  FOR T_LIBRO
   BEFORE INSERT
   AS
   BEGIN
      NEW.NEJ = 0;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BUT_LIBRO
    TABLA:   T_LIBRO
    TIPO:    BU
    PROCESO: NO PERMITO CAMBIO DE ISBN
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BUT_LIBRO  FOR T_LIBRO
   BEFORE UPDATE
   AS
   BEGIN
      IF ( OLD.ISBN <> NEW.ISBN ) THEN EXCEPTION EX_T_LIBRO1;
      IF ( NEW.NEJ < OLD.NEJ ) THEN BEGIN
         IF ( NEW.NEJ <> (OLD.NEJ - 1) ) THEN EXCEPTION EX_T_LIBRO2;
      END
      IF ( NEW.NEJ > OLD.NEJ ) THEN BEGIN
         IF ( NEW.NEJ <> (OLD.NEJ + 1) ) THEN EXCEPTION EX_T_LIBRO2;
      END
   END !!
SET TERM ; !!


-- ///////////////////////////////////////////////////////////
-- FIN DE T_LIBRO
-- ///////////////////////////////////////////////////////////

SET ECHO ON;
/*
    NOMBRE:  TRG_BIT_EJEMPLAR
    TABLA:   T_EJEMPLAR
    TIPO:    BI
    PROCESO: NRO = NEJ + 1
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BIT_EJEMPLAR  FOR T_EJEMPLAR
   BEFORE INSERT
   AS
      DECLARE VARIABLE NRO_EJEMPLAR INTEGER;
   BEGIN
      SELECT NEJ FROM T_LIBRO WHERE ISBN = NEW.ISBN INTO :NRO_EJEMPLAR;
      NEW.NRO = NRO_EJEMPLAR + 1;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_AIT_EJEMPLAR
    TABLA:   T_EJEMPLAR
    TIPO:    AI
    PROCESO: NEJ = NRO
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_AIT_EJEMPLAR  FOR T_EJEMPLAR
   AFTER INSERT
   AS
   BEGIN
      UPDATE T_LIBRO SET NEJ = NEW.NRO WHERE ISBN = NEW.ISBN;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BUT_EJEMPLAR
    TABLA:   T_EJEMPLAR
    TIPO:    BU
    PROCESO: NO PERMITO CAMBIO DE ISBN o NRO
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BUT_EJEMPLAR  FOR T_EJEMPLAR
   BEFORE UPDATE
   AS
   BEGIN
      IF ( OLD.ISBN <> NEW.ISBN OR OLD.NRO <> NEW.NRO ) THEN EXCEPTION EX_T_LIBRO1;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BDT_EJEMPLAR
    TABLA:   T_EJEMPLAR
    TIPO:    BD
    PROCESO: NRO DEBE SER IGUAL A NEJ
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BDT_EJEMPLAR  FOR T_EJEMPLAR
   BEFORE DELETE
   AS
      DECLARE VARIABLE NRO_EJEMPLAR INTEGER;
   BEGIN
      SELECT NEJ FROM T_LIBRO WHERE ISBN = OLD.ISBN INTO :NRO_EJEMPLAR;
      IF ( OLD.NRO <> NRO_EJEMPLAR ) THEN EXCEPTION EX_T_EJEMPLAR1;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_ADT_EJEMPLAR
    TABLA:   T_EJEMPLAR
    TIPO:    AD
    PROCESO: NEJ = NEJ - 1
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_ADT_EJEMPLAR  FOR T_EJEMPLAR
   AFTER DELETE
   AS
   BEGIN
      UPDATE T_LIBRO SET NEJ = NEJ - 1 WHERE ISBN = OLD.ISBN;
   END !!
SET TERM ; !!

-- ///////////////////////////////////////////////////////////
-- FIN DE T_EJEMPLAR
-- ///////////////////////////////////////////////////////////

SHOW TRIGGERS;

SET ECHO ON;

/*  Fin Creacion de triggers */
